@@ -11,7 +11,7 @@ update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
 iptables -t raw -D OUTPUT -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j NOTRACK
 
 # Ignore (return to the main chain) all packets from our agent proxy
-iptables -t nat -D "${chain_name}" -m owner --uid-owner "${aembit_group_id}" -j RETURN
+iptables -t nat -D "${chain_name}" -m owner --gid-owner "${aembit_group_id}" -j RETURN
 
 # Ignore TCP loopback
 iptables -t nat -D "${chain_name}" -p tcp -o lo -j RETURN
